@@ -94,6 +94,7 @@ sub fr {
         confirmDeleteConf       => "Vous allez effacer cette configuration. Confirmez-vous ?",
         configurationDeleted    => 'Configuration &eacute;ffac&eacute;e',
         configurationNotDeleted => 'Configuration non &eacute;ffac&eacute;e',
+        invalidVirtualHostName  => "Nom de d'hte virtuel incorrect",       
     };
 }
 
@@ -157,5 +158,6 @@ sub en {
         confirmDeleteConf       => "You're going to delete configuration. Do you confirm ?",
         configurationDeleted    => 'Configuration deleted',
         configurationNotDeleted => 'Configuration not deleted',
+        invalidVirtualHostName  => 'Invalid virtual host name',       
     };
 }
